# NLP project
This is an attempt to build a reinforcement learning model for generating trading signals. It uses a limited vocabulary such as 'go-long', 'go-short' and 'do-nothing'.
## Usage
Install the project with:
```
pip install defirl
```
Then:
```
from defirl.defi import main as RLmodel
```

# Warning
This is not financial advise. NLP project is entirely on its preliminary stages. Use it at your own risk.
